@@ -32,14 +32,6 @@ setMethodS3("findByChipType", "AffymetrixTabularFile", function(static, chipType
 
 
 
-setMethodS3("fromChipType", "AffymetrixTabularFile", function(static, ...) {
-  className <- class(static)[1];
-  msg <- sprintf("%s$fromChipType() is defunct. Use %s$byChipType() instead.", 
-                                                        className, className);
-  throw(msg);
-}, static=TRUE, deprecated=TRUE)
-
-
 setMethodS3("byChipType", "AffymetrixTabularFile", function(static, chipType, tags=NULL, ...) {
   # Search for the genome information file
   pathname <- findByChipType(static, chipType, tags=tags, ...);
