@@ -40,12 +40,22 @@ setMethodS3("as.character", "AromaChipTypeAnnotationFile", function(x, ...) {
   s <- sprintf("%s:", class(this)[1]);
   s <- c(s, sprintf("Path: %s", getPath(this)));
   s <- c(s, sprintf("Filename: %s", getFilename(this)));
-  s <- c(s, sprintf("Filesize: %.2fMB", getFileSize(this)/1024^2));
+
+  # File size
+  fileSize <- getFileSize(this, "units");
+  if (!is.na(fileSize)) {
+    fileSizeB <- sprintf("%.0f bytes", getFileSize(this, "numeric"));
+    if (fileSizeB != fileSize) {
+      fileSize <- sprintf("%s (%s)", fileSize, fileSizeB);
+    }
+  }
+  s <- c(s, sprintf("File size: %s", fileSize));
+
   s <- c(s, sprintf("Chip type: %s", getChipType(this)));
   s <- c(s, sprintf("RAM: %.2fMB", objectSize(this)/1024^2));
   class(s) <- "GenericSummary";
   s;
-}, private=TRUE)
+}, protected=TRUE)
 
 
 
@@ -176,14 +186,6 @@ setMethodS3("byName", "AromaChipTypeAnnotationFile", function(static, ...) {
 }, static=TRUE, protected=TRUE)
 
 
-setMethodS3("fromChipType", "AromaChipTypeAnnotationFile", function(static, ...) {
-  className <- class(static)[1];
-  msg <- sprintf("%s$fromChipType() is defunct. Use %s$byChipType() instead.", 
-                                                        className, className);
-  throw(msg);
-}, static=TRUE, deprecated=TRUE)
-
-
 
 
 setMethodS3("getDefaultExtension", "AromaChipTypeAnnotationFile", function(static, ...) {
@@ -237,7 +239,7 @@ setMethodS3("getDefaultExtension", "AromaChipTypeAnnotationFile", function(stati
 # @keyword IO
 # @keyword programming
 #*/###########################################################################
-setMethodS3("findByChipType", "AromaChipTypeAnnotationFile", abstract=TRUE);
+setMethodS3("findByChipType", "AromaChipTypeAnnotationFile", abstract=TRUE, protected=TRUE);
 
 
 
@@ -282,6 +284,9 @@ setMethodS3("getChipType", "AromaChipTypeAnnotationFile", abstract=TRUE);
 
 ############################################################################
 # HISTORY:
+# 2012-10-18
+# o Now as.character() for AromaChipTypeAnnotationFile reports the file
+#   size as "24.66 MB (25853850 bytes)" and not just as "24.66 MB".
 # 2012-06-18
 # o FIX: Fixed a type in an error message generated by byChipType()
 #   for AromaChipTypeAnnotationFile.
