@@ -45,7 +45,7 @@ setConstructorS3("BasePositionNormalization", function(..., model=c("smooth.spli
 
 
 setMethodS3("getAsteriskTags", "BasePositionNormalization", function(this, collapse=NULL, ...) {
-  tags <- NextMethod("getAsteriskTags", this, collapse=collapse, ...);
+  tags <- NextMethod("getAsteriskTags", collapse=NULL);
 
   # Add model tag?
   model <- this$.model;
@@ -63,13 +63,13 @@ setMethodS3("getAsteriskTags", "BasePositionNormalization", function(this, colla
   tags <- paste(tags, collapse=collapse);
 
   tags;
-}, private=TRUE)
+}, protected=TRUE)
 
 
 
 setMethodS3("getParameters", "BasePositionNormalization", function(this, ...) {
   # Get parameters from super class
-  params <- NextMethod(generic="getParameters", object=this, ...);
+  params <- NextMethod("getParameters");
 
   params <- c(params, list(
     model = this$.model,
@@ -77,7 +77,7 @@ setMethodS3("getParameters", "BasePositionNormalization", function(this, ...) {
   ));
 
   params;
-}, private=TRUE)
+}, protected=TRUE)
 
 
 
