@@ -104,7 +104,7 @@ setMethodS3("getAM", "ChipEffectSet", function(this, other, units=NULL, ..., ver
   # Get thetas from the samples
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   verbose && enter(verbose, "Retrieving sample thetas");
-  for (aa in seq(this)) {
+  for (aa in seq_along(this)) {
     cf <- getFile(this, aa);
     theta <- getDataFlat(cf, units=map, fields="theta", verbose=less(verbose))[,"theta"];
     if (!identical(length(theta), nTheta)) {
@@ -253,7 +253,7 @@ setMethodS3("getXAM", "ChipEffectSet", function(this, other, chromosome, units=N
   verbose && exit(verbose);
 
   xam;
-}) # getXAM()
+}, protected=TRUE) # getXAM()
 
 
 ############################################################################
