@@ -90,29 +90,20 @@ setConstructorS3("ProbeLevelTransform3", function(dataSet=NULL, ..., unitsToFit=
 
 
   extend(ProbeLevelTransform(dataSet=dataSet, ...), "ProbeLevelTransform3",
-    shift = shift,
+    "cached:.cellsToUpdate" = NULL,
+    "cached:.cellsToFit" = NULL,
     .typesToUpdate = typesToUpdate,
     .unitsToUpdate = unitsToUpdate,
     .typesToFit = typesToFit,
     .unitsToFit = unitsToFit,
-    .extraTags = extraTags
+    .extraTags = extraTags,
+    shift = shift
   )
 })
 
 
-setMethodS3("clearCache", "ProbeLevelTransform3", function(this, ...) {
-  # Clear all cached values.
-  for (ff in c(".cellsToUpdate", ".cellsToFit")) {
-    this[[ff]] <- NULL;
-  }
-
-  # Then for this object 
-  NextMethod("clearCache", object=this, ...);
-})
-
-
 setMethodS3("getAsteriskTags", "ProbeLevelTransform3", function(this, collapse=NULL, ...) {
-  tags <- NextMethod("getAsteriskTags", this, collapse=collapse, ...);
+  tags <- NextMethod("getAsteriskTags", collapse=NULL);
 
   # Extra tags?
   tags <- c(tags, this$.extraTags);
@@ -127,7 +118,7 @@ setMethodS3("getAsteriskTags", "ProbeLevelTransform3", function(this, collapse=N
   tags <- paste(tags, collapse=collapse);
 
   tags;
-}, private=TRUE)
+}, protected=TRUE)
 
 
 
@@ -328,7 +319,7 @@ setMethodS3("getParameters", "ProbeLevelTransform3", function(this, expand=TRUE,
   verbose && enter(verbose, "Getting algorithm parameters");
 
   # Get parameters from super class
-  params <- NextMethod(generic="getParameters", object=this, expand=expand, ...);
+  params <- NextMethod("getParameters", expand=expand);
 
   # Get local parameters
   params2 <- list(
@@ -356,7 +347,7 @@ setMethodS3("getParameters", "ProbeLevelTransform3", function(this, expand=TRUE,
   verbose && exit(verbose);
 
   params;
-}, private=TRUE)
+}, protected=TRUE)
 
 
 
