@@ -1,4 +1,4 @@
-library("R.utils");
+library("aroma.affymetrix");
 
 ##########################################################################
 # Data set:
